Security Advisories (2)
CVE-2011-4114 (2011-07-18)

PAR packed files are extracted to unsafe and predictable temporary directories (this bug was originally reported against PAR::Packer, but it applies to PAR as well).

CVE-2011-5060 (2012-01-13)

The par_mktmpdir function in the PAR module before 1.003 for Perl creates temporary files in a directory with a predictable name without verifying ownership and permissions of this directory, which allows local users to overwrite files when another user extracts a PAR packed program, a different vulnerability in a different package than CVE-2011-4114.

NAME

App::Packer::PAR - Pack applications in a single executable file

DESCRIPTION

This module is a modified version of App::Packer, temporarily shipped with PAR until it is merged into newer versions of App::Packer.

SEE ALSO

See App::Packer for the programming interface.

AUTHOR

Code modifications by Edward S. Peschko. This documentation by Autrijus Tang.

Based on the work of Mattia Barbon <mbarbon@dsi.unive.it>.

COPYRIGHT

Copyright 2004, 2005 by Edward S. Peschko, Autrijus Tang and Mattia Barbon.

This program is free software; you can redistribute it and/or modify it under the same terms as Perl itself.

See http://www.perl.com/perl/misc/Artistic.html